/*
  Example sketch to control a 28BYJ-48 stepper motor 
  with ULN2003 driver board and Arduino UNO. 
  More info: https://www.makerguides.com 
*/

// Include the Arduino Stepper.h library:
#include "Stepper.h"

// Define number of steps per rotation:
const int stepsPerRevolution = 2048;  // One full revolution is 2048 steps

// Define a smaller step size for faster response
const int stepSize = 256;  // Adjust this value for quicker movement

// Wiring:
// Pin 8 to IN1 on the ULN2003 driver
// Pin 9 to IN2 on the ULN2003 driver
// Pin 10 to IN3 on the ULN2003 driver
// Pin 11 to IN4 on the ULN2003 driver

// Create stepper object called 'myStepper', note the pin order:
Stepper myStepper = Stepper(stepsPerRevolution, 8, 10, 9, 11);

void setup() {
  // Set the speed to 10 rpm for faster movement (adjust as needed):
  myStepper.setSpeed(10);
  
  // Begin Serial communication at a baud rate of 9600:
  Serial.begin(9600);
  pinMode(5, INPUT_PULLUP);
  pinMode(7, INPUT_PULLUP);
  pinMode(13, OUTPUT);
}

void loop() {

  int switch1 = digitalRead(5);
  int switch2 = digitalRead(7);

  Serial.print("switch1 = ");
  Serial.println(switch1);
  Serial.print("switch2 = ");
  Serial.println(switch2);

  if ((switch1 == HIGH) && (switch2 == HIGH)) {
    digitalWrite(13, HIGH);
    myStepper.setSpeed(10);  // Faster speed for clockwise direction
    // Step a smaller number of steps for quicker response:
    Serial.println("clockwise speed 10");
    myStepper.step(stepSize);  // Small steps for less delay
    delay(10);
  } 
  else if ((switch1 == HIGH) && (switch2 == LOW)) {
    myStepper.step(0);
    digitalWrite(13, HIGH);
    Serial.println("Motor stopped");
    delay(10);
  }
  else if ((switch1 == LOW) && (switch2 == HIGH)) {
    myStepper.setSpeed(10);  // Faster speed for counterclockwise direction
    digitalWrite(13, LOW);
    // Step a smaller number of steps for quicker response:
    Serial.println("counterclockwise speed 10");
    myStepper.step(-stepSize);  // Small steps in reverse direction
    delay(10);
  }
}
